pub struct ResultCoreV1 {
pub iterations: u64,
pub chunks_completed: u32,
pub chunks_total: u32,
pub total_fight_time_ms: u64,
pub mean_dps_x10: u32,
pub min_dps_x10: u32,
pub max_dps_x10: u32,
pub std_dps_x10: u32,
pub ci95_half_pct_x10000: u32,
}Fields
iterations: u64chunks_completed: u32chunks_total: u32total_fight_time_ms: u64mean_dps_x10: u32min_dps_x10: u32max_dps_x10: u32std_dps_x10: u32ci95_half_pct_x10000: u32Trait Implementations
Sourceimpl Clone for ResultCoreV1
impl Clone for ResultCoreV1
Sourcefn clone(&self) -> ResultCoreV1
fn clone(&self) -> ResultCoreV1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResultCoreV1
impl Debug for ResultCoreV1
Sourceimpl Default for ResultCoreV1
impl Default for ResultCoreV1
Sourceimpl Hash for ResultCoreV1
impl Hash for ResultCoreV1
Sourceimpl Message for ResultCoreV1
impl Message for ResultCoreV1
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ResultCoreV1
impl PartialEq for ResultCoreV1
impl Copy for ResultCoreV1
impl Eq for ResultCoreV1
impl StructuralPartialEq for ResultCoreV1