pub struct TimelineSnapshot {
pub markers: Vec<TimelineMarker>,
pub aura_windows: Vec<AuraWindow>,
pub cooldown_windows: Vec<CooldownWindow>,
pub phase_markers: Vec<PhaseMarker>,
pub resource_samples: Vec<ResourceSampleProto>,
pub aura_intervals: Vec<AuraIntervalProto>,
pub encounter_events: Vec<EncounterTimelineEvent>,
}Fields
markers: Vec<TimelineMarker>aura_windows: Vec<AuraWindow>cooldown_windows: Vec<CooldownWindow>phase_markers: Vec<PhaseMarker>resource_samples: Vec<ResourceSampleProto>Per-resource samples bucketed at 100ms intervals (last-sample-wins). Populated only when the trace runner is active (in-browser preview); production multi-iteration runs leave this empty.
aura_intervals: Vec<AuraIntervalProto>Aura on/off intervals on player and target. end_ms = 0 with
open_ended = true means the aura was still active at end-of-fight.
Populated only when the trace runner is active.
encounter_events: Vec<EncounterTimelineEvent>Trait Implementations
Sourceimpl Clone for TimelineSnapshot
impl Clone for TimelineSnapshot
Sourcefn clone(&self) -> TimelineSnapshot
fn clone(&self) -> TimelineSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TimelineSnapshot
impl Debug for TimelineSnapshot
Sourceimpl Default for TimelineSnapshot
impl Default for TimelineSnapshot
Sourceimpl Message for TimelineSnapshot
impl Message for TimelineSnapshot
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for TimelineSnapshot
impl PartialEq for TimelineSnapshot
impl StructuralPartialEq for TimelineSnapshot